==> qtcreator_4.8.1.orig.tar.xz: qt-creator-opensource-src-4.8.1/src/tools/clangpchmanagerbackend/source/taskschedulerinterface.h <==
/****************************************************************************
**
** Copyright (C) 2018 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <vector>

namespace ClangBackEnd {

using uint = unsigned int;

template <typename Task>
class TaskSchedulerInterface
{
public:
    TaskSchedulerInterface() = default;
    TaskSchedulerInterface(const TaskSchedulerInterface &) = delete;
    TaskSchedulerInterface &operator=(const TaskSchedulerInterface &) = delete;

    virtual void addTasks(std::vector<Task> &&tasks) = 0;
    virtual uint freeSlots() = 0;

protected:
    ~TaskSchedulerInterface() = default;
};

} // namespace ClangBackEnd

==> qtcreator_4.11.0.orig.tar.xz: qt-creator-opensource-src-4.11.0/src/tools/clangpchmanagerbackend/source/taskschedulerinterface.h <==
/****************************************************************************
**
** Copyright (C) 2018 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <vector>

namespace ClangBackEnd {

using uint = unsigned int;

struct SlotUsage
{
    SlotUsage() = default;
    SlotUsage(uint free, uint used)
        : free(free)
        , used(used)
    {}
    uint free = 0;
    uint used = 0;
};

template <typename Task>
class TaskSchedulerInterface
{
public:
    TaskSchedulerInterface() = default;
    TaskSchedulerInterface(const TaskSchedulerInterface &) = delete;
    TaskSchedulerInterface &operator=(const TaskSchedulerInterface &) = delete;

    virtual void addTasks(std::vector<Task> &&tasks) = 0;
    virtual SlotUsage slotUsage() = 0;

protected:
    ~TaskSchedulerInterface() = default;
};

} // namespace ClangBackEnd
